@@ -15,10 +15,6 @@
 
 """Mozilla CommonVoice Dataset Builder UnitTest."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from tensorflow_datasets.audio import commonvoice
 import tensorflow_datasets.testing as tfds_test
 
