@@ -13,16 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Default values for some parameters of the API when no values are passed."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # IMPORTANT: when changing values here, update docstrings.
 
 import os
+from typing import List, Optional
+
+from tensorflow_datasets.core.utils import type_utils
 
 # Github base URL
 SRC_BASE_URL = 'https://github.com/tensorflow/datasets/tree/master/'
@@ -58,9 +56,34 @@ def add_data_dir(data_dir):
   _registered_data_dir.add(data_dir)
 
 
-def list_data_dirs():
-  """Return the list of all registered `data_dir`."""
-  all_data_dirs = _registered_data_dir | {DATA_DIR}
-  return sorted(os.path.expanduser(d) for d in all_data_dirs)
+def list_data_dirs(
+    given_data_dir: Optional[str] = None,
+) -> List[str]:
+  """Return the list of all `data_dir` to look-up.
+
+  Args:
+    given_data_dir: If a `data_dir` is provided, only the explicitly given
+      `data_dir` will be returned, otherwise the list of all registered data_dir
+      is returned
+
+  Returns:
+    The list of all data_dirs to look-up.
+  """
+  # If the data dir is explicitly given, no need to search everywhere.
+  if given_data_dir:
+    return [given_data_dir]
+  else:
+    all_data_dirs = _registered_data_dir | {DATA_DIR}
+    return sorted(os.path.expanduser(d) for d in all_data_dirs)
+
+
+def get_default_data_dir(
+    given_data_dir: Optional[str] = None,
+) -> str:
+  """Returns the default data_dir."""
+  if given_data_dir:
+    return os.path.expanduser(given_data_dir)
+  else:
+    return os.path.expanduser(DATA_DIR)
 
 
