@@ -13,25 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """DatasetBuilder base class."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import abc
 import functools
 import inspect
 import itertools
 import os
 import sys
+from typing import Any, ClassVar, Dict, List, Optional, Union
 
 from absl import logging
+import dataclasses
 import six
 import tensorflow.compat.v2 as tf
 
-from tensorflow_datasets.core import api_utils
 from tensorflow_datasets.core import constants
 from tensorflow_datasets.core import download
 from tensorflow_datasets.core import lazy_imports_lib
@@ -47,6 +43,14 @@ from tensorflow_datasets.core.utils import read_config as read_config_lib
 
 import termcolor
 
+if six.PY3:
+  import pathlib  # pylint: disable=g-import-not-at-top
+else:
+  pathlib = Any
+
+
+VersionOrStr = Union[utils.Version, str]
+
 
 FORCE_REDOWNLOAD = download.GenerateMode.FORCE_REDOWNLOAD
 REUSE_CACHE_IF_EXISTS = download.GenerateMode.REUSE_CACHE_IF_EXISTS
@@ -65,46 +69,25 @@ GCS bucket (recommended if you're running on GCP), you can instead pass
 _is_py2_download_and_prepare_disabled = True
 
 
-class BuilderConfig(object):
+@dataclasses.dataclass(eq=False)
+class BuilderConfig:
   """Base class for `DatasetBuilder` data configuration.
 
   DatasetBuilder subclasses with data configuration options should subclass
   `BuilderConfig` and add their own properties.
   """
+  # TODO(py3.10): Should update dataclass to be:
+  # * Frozen (https://bugs.python.org/issue32953)
+  # * Kwargs-only (https://bugs.python.org/issue33129)
 
-  @api_utils.disallow_positional_args
-  def __init__(self, name, version=None, supported_versions=None,
-               description=None):
-    self._name = name
-    self._version = version
-    self._supported_versions = supported_versions or []
-    self._description = description
-
-  @property
-  def name(self):
-    return self._name
-
-  @property
-  def version(self):
-    return self._version
-
-  @property
-  def supported_versions(self):
-    return self._supported_versions
-
-  @property
-  def description(self):
-    return self._description
-
-  def __repr__(self):
-    return "<{cls_name} name={name}, version={version}>".format(
-        cls_name=type(self).__name__,
-        name=self.name,
-        version=self.version or "None")
+  name: str
+  version: Optional[VersionOrStr] = None
+  release_notes: Optional[Dict[str, str]] = None
+  supported_versions: List[str] = dataclasses.field(default_factory=list)
+  description: Optional[str] = None
 
 
-@six.add_metaclass(registered.RegisteredDataset)
-class DatasetBuilder(object):
+class DatasetBuilder(registered.RegisteredDataset):
   """Abstract base class for all datasets.
 
   `DatasetBuilder` has 3 key methods:
@@ -140,12 +123,14 @@ class DatasetBuilder(object):
   ```
   """
 
-  # Name of the dataset, filled by metaclass based on class name.
-  name = None
-
   # Semantic version of the dataset (ex: tfds.core.Version('1.2.0'))
   VERSION = None
 
+  # Release notes
+  # Metadata only used for documentation. Should be a dict[version,description]
+  # Multi-lines are automatically dedent
+  RELEASE_NOTES: ClassVar[Dict[str, str]] = {}
+
   # List dataset versions which can be loaded using current code.
   # Data can only be prepared with canonical VERSION or above.
   SUPPORTED_VERSIONS = []
@@ -153,10 +138,6 @@ class DatasetBuilder(object):
   # Named configurations that modify the data generated by download_and_prepare.
   BUILDER_CONFIGS = []
 
-  # Set to True for datasets that are under active development and should not
-  # be available through tfds.{load, builder} or documented in overview.md.
-  IN_DEVELOPMENT = False
-
   # Must be set for datasets that use 'manual_dir' functionality - the ones
   # that require users to do additional steps to download the data
   # (this is usually due to some external regulations / rules).
@@ -166,37 +147,39 @@ class DatasetBuilder(object):
   # displayed in the dataset documentation.
   MANUAL_DOWNLOAD_INSTRUCTIONS = None
 
-
-  @api_utils.disallow_positional_args
-  def __init__(self, data_dir=None, config=None, version=None):
+  def __init__(
+      self,
+      *,
+      data_dir: Optional[utils.PathLike] = None,
+      config: Union[None, str, BuilderConfig] = None,
+      version: Union[None, str, utils.Version] = None,
+  ):
     """Constructs a DatasetBuilder.
 
     Callers must pass arguments as keyword arguments.
 
     Args:
-      data_dir: `str`, directory to read/write data. Defaults to the value of
+      data_dir: directory to read/write data. Defaults to the value of
         the environment variable TFDS_DATA_DIR, if set, otherwise falls back to
         "~/tensorflow_datasets".
       config: `tfds.core.BuilderConfig` or `str` name, optional configuration
         for the dataset that affects the data generated on disk. Different
         `builder_config`s will have their own subdirectories and versions.
-      version: `str`. Optional version at which to load the dataset. An error is
+      version: Optional version at which to load the dataset. An error is
         raised if specified version cannot be satisfied. Eg: '1.2.3', '1.2.*'.
         The special value "experimental_latest" will use the highest version,
         even if not default. This is not recommended unless you know what you
         are doing, as the version could be broken.
     """
+    if data_dir:
+      data_dir = os.fspath(data_dir)  # Pathlib -> str
+
     # For pickling:
     self._original_state = dict(data_dir=data_dir, config=config,
                                 version=version)
     # To do the work:
     self._builder_config = self._create_builder_config(config)
     # Extract code version (VERSION or config)
-    if not self._builder_config and not self.VERSION:
-      raise AssertionError(
-          "DatasetBuilder {} does not have a defined version. Please add a "
-          "`VERSION = tfds.core.Version('x.y.z')` to the class.".format(
-              self.name))
     self._version = self._pick_version(version)
     # Compute the base directory (for download) and dataset/version directory.
     self._data_dir_root, self._data_dir = self._build_data_dir(data_dir)
@@ -205,6 +188,12 @@ class DatasetBuilder(object):
     else:  # Use the code version (do not restore data)
       self.info.initialize_from_bucket()
 
+  @utils.classproperty
+  @classmethod
+  def code_path(cls) -> pathlib.Path:
+    """Returns the path to the file where the Dataset class is located."""
+    return pathlib.Path(inspect.getfile(cls))
+
   def __getstate__(self):
     return self._original_state
 
@@ -235,6 +224,12 @@ class DatasetBuilder(object):
 
   def _pick_version(self, requested_version):
     """Returns utils.Version instance, or raise AssertionError."""
+    if not self._builder_config and not self.VERSION:
+      raise AssertionError(
+          "DatasetBuilder {} does not have a defined version. Please add a "
+          "`VERSION = tfds.core.Version('x.y.z')` to the class.".format(
+              self.name))
+
     if requested_version == "experimental_latest":
       return max(self.versions)
     for version in self.versions:
@@ -253,6 +248,23 @@ class DatasetBuilder(object):
   def data_dir(self):
     return self._data_dir
 
+  @utils.classproperty
+  @classmethod
+  @functools.lru_cache(maxsize=None)
+  def url_infos(cls) -> Optional[Dict[str, download.checksums.UrlInfo]]:
+    """Load `UrlInfo` from the given path."""
+    # Search for the url_info file.
+    checksums_path = cls.code_path.parent / "checksums.tsv"
+    if checksums_path.exists():
+      checksums_path = str(checksums_path)
+    else:
+      checksums_path = None
+    # If url_info file is found, load the urls
+    if checksums_path:
+      return download.checksums.url_infos_from_path(checksums_path)
+    else:
+      return None
+
   @utils.memoized_property
   def info(self):
     """`tfds.core.DatasetInfo` for this builder."""
@@ -268,8 +280,7 @@ class DatasetBuilder(object):
           "the restored dataset.")
     return self._info()
 
-  @api_utils.disallow_positional_args
-  def download_and_prepare(self, download_dir=None, download_config=None):
+  def download_and_prepare(self, *, download_dir=None, download_config=None):
     """Downloads and prepares dataset for reading.
 
     Args:
@@ -407,10 +418,10 @@ class DatasetBuilder(object):
           self.info.write_to_directory(self._data_dir)
     self._log_download_done()
 
-  @api_utils.disallow_positional_args
   def as_dataset(
       self,
       split=None,
+      *,
       batch_size=None,
       shuffle_files=False,
       decoders=None,
@@ -566,7 +577,9 @@ class DatasetBuilder(object):
       ds = ds.map(lambda fs: (fs[input_f], fs[target_f]),
                   num_parallel_calls=tf.data.experimental.AUTOTUNE)
 
-    ds = ds.prefetch(tf.data.experimental.AUTOTUNE)
+    # Add prefetch by default
+    if not read_config.skip_prefetch:
+      ds = ds.prefetch(tf.data.experimental.AUTOTUNE)
 
     # If shuffling is True and seeds not set, allow pipeline to be
     # non-deterministic
@@ -650,24 +663,22 @@ class DatasetBuilder(object):
     builder_dir = self._relative_data_dir(with_version=False)
     version_dir = self._relative_data_dir(with_version=True)
 
-    # If the data dir is explicitly given, no need to search everywhere.
-    if given_data_dir:
-      default_data_dir = os.path.expanduser(given_data_dir)
-      all_data_dirs = [default_data_dir]
-    else:
-      default_data_dir = os.path.expanduser(constants.DATA_DIR)
-      all_data_dirs = constants.list_data_dirs()
+    default_data_dir = constants.get_default_data_dir(
+        given_data_dir=given_data_dir
+    )
+    all_data_dirs = constants.list_data_dirs(given_data_dir=given_data_dir)
 
-    all_version_dirs = set()
+    all_versions = set()
     requested_version_dirs = {}
     for data_dir_root in all_data_dirs:
       # List all existing versions
-      all_version_dirs.update(
-          _list_all_version_dirs(os.path.join(data_dir_root, builder_dir)))
-      # Check for existance of the requested dir
-      requested_version_dir = os.path.join(data_dir_root, version_dir)
-      if requested_version_dir in all_version_dirs:
-        requested_version_dirs[data_dir_root] = requested_version_dir
+      full_builder_dir = os.path.join(data_dir_root, builder_dir)
+      all_versions.update(utils.version.list_all_versions(full_builder_dir))
+      # Check for existance of the requested version
+      if self.version in all_versions:
+        requested_version_dirs[data_dir_root] = os.path.join(
+            data_dir_root, version_dir
+        )
 
     if len(requested_version_dirs) > 1:
       raise ValueError(
@@ -679,12 +690,12 @@ class DatasetBuilder(object):
 
     # No dataset found, use default directory
     data_dir = os.path.join(default_data_dir, version_dir)
-    if all_version_dirs:
+    if all_versions:
       logging.warning(
           "Found a different version of the requested dataset:\n"
           "%s\n"
           "Using %s instead.",
-          "\n".join(sorted(all_version_dirs)),
+          "\n".join(str(v) for v in sorted(all_versions)),
           data_dir
       )
     return default_data_dir, data_dir
@@ -779,6 +790,7 @@ class DatasetBuilder(object):
         download_dir=download_dir,
         extract_dir=extract_dir,
         manual_dir=manual_dir,
+        url_infos=self.url_infos,
         manual_dir_instructions=utils.dedent(self.MANUAL_DOWNLOAD_INSTRUCTIONS),
         force_download=(download_config.download_mode == FORCE_REDOWNLOAD),
         force_extraction=(download_config.download_mode == FORCE_REDOWNLOAD),
@@ -836,26 +848,15 @@ class DatasetBuilder(object):
     return config_dict
 
 
-def _list_all_version_dirs(root_dir):
-  """Lists all dataset versions present on disk."""
-  if not tf.io.gfile.exists(root_dir):
-    return []
+class FileReaderBuilder(DatasetBuilder):
+  """Base class for datasets reading files.
 
-  def _is_version_valid(version):
-    try:
-      return utils.Version(version) and True
-    except ValueError:  # Invalid version (ex: incomplete data dir)
-      return False
+  Subclasses are:
 
-  return [  # Return all version dirs
-      os.path.join(root_dir, version)
-      for version in tf.io.gfile.listdir(root_dir)
-      if _is_version_valid(version)
-  ]
+   * `FileAdapterBuilder`: Can both generate and read generated dataset.
+   * `ReadOnlyBuilder`: Can only read pre-generated datasets.
 
-
-class FileAdapterBuilder(DatasetBuilder):
-  """Base class for datasets with data generation based on file adapter."""
+  """
 
   @utils.memoized_property
   def _example_specs(self):
@@ -865,6 +866,28 @@ class FileAdapterBuilder(DatasetBuilder):
   def _tfrecords_reader(self):
     return tfrecords_reader.Reader(self._data_dir, self._example_specs)
 
+  def _as_dataset(
+      self,
+      split=splits_lib.Split.TRAIN,
+      decoders=None,
+      read_config=None,
+      shuffle_files=False):
+    ds = self._tfrecords_reader.read(
+        name=self.name,
+        instructions=split,
+        split_infos=self.info.splits.values(),
+        read_config=read_config,
+        shuffle_files=shuffle_files,
+    )
+    decode_fn = functools.partial(
+        self.info.features.decode_example, decoders=decoders)
+    ds = ds.map(decode_fn, num_parallel_calls=tf.data.experimental.AUTOTUNE)
+    return ds
+
+
+class FileAdapterBuilder(FileReaderBuilder):
+  """Base class for datasets with data generation based on file adapter."""
+
   @abc.abstractmethod
   def _split_generators(self, dl_manager):
     """Specify feature dictionary generators and dataset splits.
@@ -953,24 +976,6 @@ class FileAdapterBuilder(DatasetBuilder):
     # Update the info object with the splits.
     self.info.update_splits_if_different(split_dict)
 
-  def _as_dataset(
-      self,
-      split=splits_lib.Split.TRAIN,
-      decoders=None,
-      read_config=None,
-      shuffle_files=False):
-    ds = self._tfrecords_reader.read(
-        name=self.name,
-        instructions=split,
-        split_infos=self.info.splits.values(),
-        read_config=read_config,
-        shuffle_files=shuffle_files,
-    )
-    decode_fn = functools.partial(
-        self.info.features.decode_example, decoders=decoders)
-    ds = ds.map(decode_fn, num_parallel_calls=tf.data.experimental.AUTOTUNE)
-    return ds
-
 
 class GeneratorBasedBuilder(FileAdapterBuilder):
   """Base class for datasets with data generation based on dict generators.
