@@ -13,15 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Tests for tensorflow_datasets.core.dataset_builder."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import tempfile
+from unittest import mock
 
 from absl.testing import absltest
 import dill
@@ -34,7 +30,7 @@ from tensorflow_datasets.core import dataset_info
 from tensorflow_datasets.core import dataset_utils
 from tensorflow_datasets.core import download
 from tensorflow_datasets.core import features
-from tensorflow_datasets.core import registered
+from tensorflow_datasets.core import load
 from tensorflow_datasets.core import splits as splits_lib
 from tensorflow_datasets.core import utils
 from tensorflow_datasets.core.utils import read_config as read_config_lib
@@ -119,7 +115,7 @@ class DatasetBuilderTest(testing.TestCase):
   @testing.run_in_graph_and_eager_modes()
   def test_load(self):
     with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
-      dataset = registered.load(
+      dataset = load.load(
           name="dummy_dataset_with_configs",
           data_dir=tmp_dir,
           download=True,
@@ -160,12 +156,12 @@ class DatasetBuilderTest(testing.TestCase):
           side_effect=NotImplementedError):
         # Make sure the dataset cannot be generated.
         with self.assertRaises(NotImplementedError):
-          registered.load(
+          load.load(
               name="mnist",
               data_dir=tmp_dir)
         # Enable GCS access so that dataset will be loaded from GCS.
         with self.gcs_access():
-          _, info = registered.load(
+          _, info = load.load(
               name="mnist",
               data_dir=tmp_dir,
               with_info=True)
@@ -352,7 +348,7 @@ class DatasetBuilderTest(testing.TestCase):
       with self.assertRaisesWithPredicateMatch(
           ValueError, "`all` is a special"):
         # Raise error during .download_and_prepare()
-        registered.load(
+        load.load(
             name="invalid_split_dataset",
             data_dir=tmp_dir,
         )
@@ -459,6 +455,22 @@ class DatasetBuilderMultiDirTest(testing.TestCase):
     self.assertBuildDataDir(
         self.builder._build_data_dir(self.other_data_dir), self.other_data_dir)
 
+  def test_load_data_dir(self):
+    """Ensure that `tfds.load` also supports multiple data_dir."""
+    constants.add_data_dir(self.other_data_dir)
+
+    class MultiDirDataset(DummyDatasetSharedGenerator):  # pylint: disable=unused-variable
+      VERSION = utils.Version("1.2.0")
+
+    data_dir = os.path.join(
+        self.other_data_dir, "multi_dir_dataset", "1.2.0"
+    )
+    tf.io.gfile.makedirs(data_dir)
+
+    with mock.patch.object(dataset_info.DatasetInfo, "read_from_directory"):
+      _, info = load.load("multi_dir_dataset", split=[], with_info=True)
+    self.assertEqual(info.data_dir, data_dir)
+
 
 class BuilderPickleTest(testing.TestCase):
 
@@ -527,7 +539,10 @@ class BuilderRestoreGcsTest(testing.TestCase):
       self.assertEqual(builder.info.splits["train"].statistics.num_examples, 20)
       self.assertFalse(self.compute_dynamic_property.called)
 
-      dl_config = download.DownloadConfig(max_examples_per_split=5)
+      dl_config = download.DownloadConfig(
+          max_examples_per_split=5,
+          compute_stats=download.ComputeStatsMode.AUTO,
+      )
       builder.download_and_prepare(download_config=dl_config)
 
       # Statistics should have been recomputed (split different from the
@@ -544,7 +559,10 @@ class BuilderRestoreGcsTest(testing.TestCase):
       self.assertEqual(builder.info.splits.total_num_examples, 0)
       self.assertFalse(self.compute_dynamic_property.called)
 
-      builder.download_and_prepare()
+      dl_config = download.DownloadConfig(
+          compute_stats=download.ComputeStatsMode.AUTO,
+      )
+      builder.download_and_prepare(download_config=dl_config)
 
       # Statistics should have been recomputed
       self.assertTrue(self.compute_dynamic_property.called)
@@ -763,7 +781,7 @@ class NestedSequenceBuilderTest(testing.TestCase):
   @testing.run_in_graph_and_eager_modes()
   def test_nested_sequence(self):
     with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
-      ds_train, ds_info = registered.load(
+      ds_train, ds_info = load.load(
           name="nested_sequence_builder",
           data_dir=tmp_dir,
           split="train",
