@@ -13,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """DatasetInfo records the information we know about a dataset.
 
 This includes things that we know about the dataset statically, i.e.:
@@ -31,10 +30,6 @@ processed the dataset as well:
  - etc.
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import abc
 import json
 import os
@@ -45,11 +40,11 @@ from absl import logging
 import six
 import tensorflow.compat.v2 as tf
 
-from tensorflow_datasets.core import api_utils
 from tensorflow_datasets.core import lazy_imports_lib
 from tensorflow_datasets.core import naming
 from tensorflow_datasets.core import splits as splits_lib
 from tensorflow_datasets.core import utils
+from tensorflow_datasets.core.features import feature as feature_lib
 from tensorflow_datasets.core.features import top_level_feature
 from tensorflow_datasets.core.proto import dataset_info_pb2
 from tensorflow_datasets.core.utils import gcs_utils
@@ -90,8 +85,8 @@ class DatasetInfo(object):
   builder.download_and_prepare()`).
   """
 
-  @api_utils.disallow_positional_args
   def __init__(self,
+               *,
                builder,
                description=None,
                features=None,
@@ -130,6 +125,9 @@ class DatasetInfo(object):
         name=builder.name,
         description=utils.dedent(description),
         version=str(builder._version),  # pylint: disable=protected-access
+        config_name=(
+            builder.builder_config.name if builder.builder_config else None
+        ),
         citation=utils.dedent(citation),
         redistribution_info=dataset_info_pb2.RedistributionInfo(
             license=utils.dedent(redistribution_info.pop("license")),
@@ -143,7 +141,6 @@ class DatasetInfo(object):
         raise ValueError(
             "DatasetInfo.features only supports FeaturesDict or Sequence at "
             "the top-level. Got {}".format(features))
-      features._set_top_level()  # pylint: disable=protected-access
     self._features = features
     self._splits = splits_lib.SplitDict(self._builder.name)
     if supervised_keys is not None:
@@ -325,9 +322,9 @@ class DatasetInfo(object):
 
   def write_to_directory(self, dataset_info_dir):
     """Write `DatasetInfo` as JSON to `dataset_info_dir`."""
-    # Save the metadata from the features (vocabulary, labels,...)
+    # Save the features structure & metadata (vocabulary, labels,...)
     if self.features:
-      self.features.save_metadata(dataset_info_dir)
+      self.features.save_config(dataset_info_dir)
 
     # Save any additional metadata
     if self.metadata is not None:
@@ -369,7 +366,11 @@ class DatasetInfo(object):
     # Restore the feature metadata (vocabulary, labels names,...)
     if self.features:
       self.features.load_metadata(dataset_info_dir)
-
+    # For `ReadOnlyBuilder`, reconstruct the features from the config.
+    elif tf.io.gfile.exists(feature_lib.make_config_path(dataset_info_dir)):
+      self._features = feature_lib.FeatureConnector.from_config(
+          dataset_info_dir
+      )
     if self.metadata is not None:
       self.metadata.load_metadata(dataset_info_dir)
 
@@ -516,6 +517,23 @@ def read_from_json(json_filename):
   return parsed_proto
 
 
+def pack_as_supervised_ds(
+    ds: tf.data.Dataset,
+    ds_info: DatasetInfo,
+) -> tf.data.Dataset:
+  """Pack `(input, label)` dataset as `{'key0': input, 'key1': label}`."""
+  if (
+      ds_info.supervised_keys
+      and isinstance(ds.element_spec, tuple)
+      and len(ds.element_spec) == 2
+  ):
+    x_key, y_key = ds_info.supervised_keys
+    ds = ds.map(lambda x, y: {x_key: x, y_key: y})
+    return ds
+  else:  # If dataset isn't a supervised tuple (input, label), return as-is
+    return ds
+
+
 @six.add_metaclass(abc.ABCMeta)
 class Metadata(dict):
   """Abstract base class for DatasetInfo metadata container.
