@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Tests for tensorflow_datasets.core.dataset_info."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import json
 import os
 import tempfile
@@ -29,6 +24,7 @@ import tensorflow.compat.v2 as tf
 from tensorflow_datasets import testing
 from tensorflow_datasets.core import dataset_builder
 from tensorflow_datasets.core import dataset_info
+from tensorflow_datasets.core import download
 from tensorflow_datasets.core import features
 from tensorflow_datasets.core.utils import py_utils
 from tensorflow_datasets.image_classification import mnist
@@ -135,7 +131,7 @@ class DatasetInfoTest(testing.TestCase):
     info.read_from_directory(_INFO_DIR_UNLABELED)
 
     # Assert supervised_keys has not been set
-    self.assertEqual(None, info.supervised_keys)
+    self.assertIsNone(None, info.supervised_keys)
 
   def test_writing(self):
     # First read in stuff.
@@ -264,7 +260,11 @@ class DatasetInfoTest(testing.TestCase):
   def test_statistics_generation(self):
     with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
       builder = DummyDatasetSharedGenerator(data_dir=tmp_dir)
-      builder.download_and_prepare()
+      builder.download_and_prepare(
+          download_config=download.DownloadConfig(
+              compute_stats=download.ComputeStatsMode.AUTO,
+          ),
+      )
 
       # Overall
       self.assertEqual(30, builder.info.splits.total_num_examples)
@@ -311,7 +311,11 @@ class DatasetInfoTest(testing.TestCase):
   def test_schema_generation_variable_sizes(self):
     with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
       builder = RandomShapedImageGenerator(data_dir=tmp_dir)
-      builder.download_and_prepare()
+      builder.download_and_prepare(
+          download_config=download.DownloadConfig(
+              compute_stats=download.ComputeStatsMode.AUTO,
+          ),
+      )
 
       expected_schema = text_format.Parse(
           """
