@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Classes to specify download or extraction information."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import base64
 import codecs
 import enum
@@ -33,7 +28,6 @@ from typing import Any
 from six.moves import urllib
 import tensorflow.compat.v2 as tf
 
-from tensorflow_datasets.core import api_utils
 from tensorflow_datasets.core.download import checksums as checksums_lib
 from tensorflow_datasets.core.utils import py_utils
 
@@ -290,8 +284,8 @@ def get_extract_method(path):
 class Resource(object):
   """Represents a resource to download, extract, or both."""
 
-  @api_utils.disallow_positional_args()
   def __init__(self,
+               *,
                url=None,
                extract_method=None,
                path=None):
