@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Tests for tensorflow_datasets.core.features.audio_feature."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import array
 import tempfile
 
@@ -41,7 +36,7 @@ class AudioFeatureTest(testing.FeatureExpectationsTestCase):
     np_audio = self.create_np_audio()
 
     self.assertFeature(
-        feature=features.Audio(),
+        feature=features.Audio(sample_rate=1000),
         shape=(None,),
         dtype=tf.int64,
         tests=[
@@ -50,6 +45,10 @@ class AudioFeatureTest(testing.FeatureExpectationsTestCase):
                 expected=np_audio,
             ),
         ],
+        test_attributes=dict(
+            _file_format=None,
+            sample_rate=1000,
+        )
     )
 
   def test_numpy_array_float(self):
@@ -89,6 +88,9 @@ class AudioFeatureTest(testing.FeatureExpectationsTestCase):
                 expected=np_audio,
             ),
         ],
+        test_attributes=dict(
+            _file_format="wav",
+        )
     )
 
   def test_file_object(self):
