@@ -13,22 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Text feature.
 
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
+import html
 import os
+import textwrap
 
 from absl import logging
 import tensorflow.compat.v2 as tf
 
+from tensorflow_datasets.core.deprecated import text as text_lib
 from tensorflow_datasets.core.features import feature
-from tensorflow_datasets.core.features import text as text_lib
+from tensorflow_datasets.core.utils import type_utils
+
+Json = type_utils.Json
 
 
 class Text(feature.Tensor):
@@ -38,9 +38,9 @@ class Text(feature.Tensor):
     """Constructs a Text FeatureConnector.
 
     Args:
-      encoder: `tfds.features.text.TextEncoder`, an encoder that can convert
+      encoder: `tfds.deprecated.text.TextEncoder`, an encoder that can convert
         text to integers. If None, the text will be utf-8 byte-encoded.
-      encoder_config: `tfds.features.text.TextEncoderConfig`, needed if
+      encoder_config: `tfds.deprecated.text.TextEncoderConfig`, needed if
         restoring from a file with `load_metadata`.
     """
     if encoder and encoder_config:
@@ -167,3 +167,33 @@ class Text(feature.Tensor):
     if self.encoder is None:
       return {}
     return {"encoder": repr(self.encoder)}
+
+  def repr_html(self, ex: bytes) -> str:
+    """Text are decoded."""
+    if self.encoder is not None:
+      return repr(ex)
+
+    ex = ex.decode("utf-8")
+    ex = html.escape(ex)
+    ex = textwrap.shorten(ex, width=1000)  # Truncate long text
+    return ex
+
+  @classmethod
+  def from_json_content(cls, value: Json) -> "Text":
+    if "use_encoder" in value:
+      raise ValueError(
+          "Deprecated encoder not supported. Please use the plain text version "
+          "with `tensorflow_text`."
+      )
+    del value  # Unused
+    return cls()
+
+  def to_json_content(self) -> Json:
+    if self._encoder or self._encoder_config:
+      logging.warning(
+          "Dataset is using deprecated text encoder API which will be removed "
+          "soon. Please use the plain_text version of the dataset and migrate "
+          "to `tensorflow_text`."
+      )
+      return dict(use_encoder=True)
+    return dict()
