@@ -13,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Stable hashing function using md5.
 
 Note that the properties we are looking at here are:
@@ -46,10 +45,6 @@ The split name is being used as salt to avoid having the same keys in two splits
 result in same order.
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import hashlib
 from typing import Union
 
