@@ -13,18 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Cityscapes Datasets."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import re
 
 import tensorflow.compat.v2 as tf
-from tensorflow_datasets.core import api_utils
 import tensorflow_datasets.public_api as tfds
 
 _CITATION = '''\
@@ -75,8 +69,7 @@ class CityscapesConfig(tfds.core.BuilderConfig):
           enables coarse grain segmentations, if segmentation labels are used.
   """
 
-  @api_utils.disallow_positional_args
-  def __init__(self, right_images=False, segmentation_labels=True,
+  def __init__(self, *, right_images=False, segmentation_labels=True,
                disparity_maps=False, train_extra_split=False, **kwargs):
     super(CityscapesConfig, self).__init__(version='1.0.0', **kwargs)
 
