@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """CBIS-DDSM mammography dataset."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import csv
 import os
 import re
@@ -123,8 +118,11 @@ class CuratedBreastImagingDDSMConfig(tfds.core.BuilderConfig):
   """BuilderConfig for CuratedBreastImagingDDSM."""
 
   def __init__(self, image_size=None, patch_size=None, **kwargs):
-    kwargs['version'] = tfds.core.Version(
-        '2.0.0', 'New split API (https://tensorflow.org/datasets/splits)')
+    kwargs['version'] = tfds.core.Version('2.0.1')
+    kwargs['release_notes'] = {
+        '2.0.1': 'New split API (https://tensorflow.org/datasets/splits)',
+    }
+
     super(CuratedBreastImagingDDSMConfig, self).__init__(**kwargs)
     self.image_size = image_size
     self.patch_size = patch_size
@@ -298,12 +296,7 @@ class CuratedBreastImagingDDSM(tfds.core.GeneratorBasedBuilder):
         'mass-test': _MASS_TEST_CSV_URL,
         'mass-train': _MASS_TRAIN_CSV_URL
     }
-    resources = {
-        key: tfds.download.Resource(
-            url=url, extract_method=tfds.download.ExtractMethod.NO_EXTRACT)
-        for key, url in resources_urls.items()
-    }
-    resource_paths = dl_manager.download_and_extract(resources)
+    resource_paths = dl_manager.download_and_extract(resources_urls)
     patients_data = _load_csv_files(dl_manager.manual_dir, resource_paths)
 
     # Statistics about the resulting splits.
@@ -413,7 +406,7 @@ class CuratedBreastImagingDDSM(tfds.core.GeneratorBasedBuilder):
           if abnormality['pathology'].startswith('MALIGNANT'):
             benign_or_malignant = 'MALIGNANT'
           else:
-            benign_or_malignant = 'BENING'
+            benign_or_malignant = 'BENIGN'
           if abnormality['type'] == 'calc':
             label = benign_or_malignant + '_CALCIFICATION'
           elif abnormality['type'] == 'mass':
@@ -593,13 +586,25 @@ def _read_image(filepath, image_size=None):
     return image
 
 
+def _find_contours(*args, **kwargs):
+  cv2 = tfds.core.lazy_imports.cv2
+  tuple_ = cv2.findContours(*args, **kwargs)
+  if len(tuple_) == 2:  # Recent opencv returns: (contours, hierachy)
+    return tuple_[0]
+  elif len(tuple_) == 3:  # Old opencv returns: (ret, contours, hierachy)
+    return tuple_[1]
+  else:
+    raise AssertionError('Unknown {}')
+
+
 def _get_breast_mask(image, min_breast_color_threshold=0.05):
   """Get the binary mask of the breast region of the image."""
   cv2 = tfds.core.lazy_imports.cv2
   threshold = int(image.max() * min_breast_color_threshold)
   _, image_binary = cv2.threshold(image, threshold, 255, cv2.THRESH_BINARY)
-  _, contours, _ = cv2.findContours(image_binary, cv2.RETR_LIST,
-                                    cv2.CHAIN_APPROX_SIMPLE)
+  contours = _find_contours(
+      image_binary, cv2.RETR_LIST, cv2.CHAIN_APPROX_SIMPLE
+  )
   contours_areas = [cv2.contourArea(cont) for cont in contours]
   biggest_contour_idx = np.argmax(contours_areas)
   return cv2.drawContours(
@@ -609,8 +614,7 @@ def _get_breast_mask(image, min_breast_color_threshold=0.05):
 
 def _get_roi_from_mask(mask):
   cv2 = tfds.core.lazy_imports.cv2
-  _, contours, _ = cv2.findContours(mask, cv2.RETR_LIST,
-                                    cv2.CHAIN_APPROX_SIMPLE)
+  contours = _find_contours(mask, cv2.RETR_LIST, cv2.CHAIN_APPROX_SIMPLE)
   contours_areas = [cv2.contourArea(cont) for cont in contours]
   biggest_contour_idx = np.argmax(contours_areas)
   return contours[biggest_contour_idx]
