@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Geirhos conflict stimulus set."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import re
 
@@ -90,8 +85,7 @@ class GeirhosConflictStimuli(tfds.core.GeneratorBasedBuilder):
     """Define splits."""
 
     dl_paths = dl_manager.download_and_extract({
-        "texture_vs_shape": tfds.download.Resource(
-            url=_DOWNLOAD_URL, extract_method=tfds.download.ExtractMethod.ZIP),
+        "texture_vs_shape": _DOWNLOAD_URL,
         "imagenet_mapping": _IMAGENET_MAPPING_URL
     })
 
