@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Imagenet subset datasets."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import io
 import os
 
@@ -76,8 +71,7 @@ class Imagenet2012Subset(Imagenet2012):
       tfds.core.BuilderConfig(  # pylint: disable=g-complex-comprehension
           name=subset_size,
           description='{} of total ImageNet training set.'.format(subset_size),
-          version=tfds.core.Version(
-              '5.0.0', ''),
+          version=tfds.core.Version('5.0.0'),
       ) for subset_size in SUBSET2FILES
   ]
 
@@ -156,4 +150,3 @@ class Imagenet2012Subset(Imagenet2012):
               'label': label,
           }
           yield image_fname, record
-
