@@ -13,17 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Imagenette: a subset of 10 easily classified classes from Imagenet.
 
 (tench, English springer, cassette player, chain saw, church, French horn,
 garbage truck, gas pump, golf ball, parachute)
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 
 import tensorflow.compat.v2 as tf
