@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """MNIST, Fashion MNIST, KMNIST and EMNIST."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import numpy as np
 from six.moves import urllib
@@ -219,8 +214,7 @@ class KMNIST(MNIST):
 class EMNISTConfig(tfds.core.BuilderConfig):
   """BuilderConfig for EMNIST CONFIG."""
 
-  @tfds.core.disallow_positional_args
-  def __init__(self, class_number, train_examples, test_examples, **kwargs):
+  def __init__(self, *, class_number, train_examples, test_examples, **kwargs):
     """BuilderConfig for EMNIST class number.
 
     Args:
