@@ -13,12 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Dataset class for Places365-Standard small(256x256) dataset."""
-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 import csv
 import os
 import six.moves.urllib as urllib
