@@ -13,16 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Datasets of the Open Images Challange 2019.
 
 https://storage.googleapis.com/openimages/web/challenge2019.html
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import abc
 
 import tensorflow.compat.v2 as tf
