@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """The Waymo Open Dataset. See waymo.com/open."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import io
 import os
 from absl import logging
@@ -68,8 +63,9 @@ _OBJECT_LABELS = [
 class WaymoOpenDatasetConfig(tfds.core.BuilderConfig):
   """BuilderConfig for Waymo Open Dataset Config."""
 
-  @tfds.core.disallow_positional_args
-  def __init__(self, name, version_str, description, is_on_gcs=False, **kwargs):
+  def __init__(
+      self, *, name, version_str, description, is_on_gcs=False, **kwargs
+  ):
     """BuilderConfig for Waymo Open Dataset examples.
 
     Args:
@@ -87,8 +83,8 @@ class WaymoOpenDatasetConfig(tfds.core.BuilderConfig):
         description=description,
         **kwargs
     )
-    self.cloud_bucket = "gs://waymo_open_dataset_{}_individual_files/".format(
-        version_str
+    self.cloud_bucket = tfds.core.gcs_path(
+        f"gs://waymo_open_dataset_{version_str}_individual_files/"
     )
 
 
