@@ -13,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Util to generate the dataset documentation content.
 
 Used by tensorflow_datasets/scripts/documentation/build_catalog.py
@@ -23,11 +22,12 @@ Used by tensorflow_datasets/scripts/documentation/build_catalog.py
 import collections
 from concurrent import futures
 import os
-from typing import Dict, List, Tuple, Union, Set
+from typing import Dict, List, Optional, Tuple, Union, Set
 
 import mako.lookup
 import tensorflow.compat.v2 as tf
 import tensorflow_datasets as tfds
+from tensorflow_datasets.scripts.documentation import dataset_markdown_builder
 
 WORKER_COUNT_DATASETS = 200
 WORKER_COUNT_CONFIGS = 50
@@ -51,8 +51,8 @@ NightlyDict = Dict[str, Union[bool, Dict[str, Union[bool, Dict[str, bool]]]]]
 class VisualizationDocUtil(object):
   """Small util which generate the path/urls for the visualizations."""
   # Url used to display images
-  BASE_PATH = tfds.core.gcs_path('visualization/')
-  BASE_URL = 'https://storage.googleapis.com/tfds-data/visualization/'
+  BASE_PATH = tfds.core.gcs_path('visualization/fig/')
+  BASE_URL = 'https://storage.googleapis.com/tfds-data/visualization/fig/'
 
   def _get_name(self, builder):
     return builder.info.full_name.replace('/', '-') + '.png'
@@ -72,7 +72,7 @@ class VisualizationDocUtil(object):
 
 def _split_full_name(full_name: str) -> Tuple[str, str, str]:
   """Extracts the `(ds name, config, version)` from the full_name."""
-  if not tfds.core.registered.is_full_name(full_name):
+  if not tfds.core.load.is_full_name(full_name):
     raise ValueError(
         f'Parsing builder name string {full_name} failed.'
         'The builder name string must be of the following format:'
@@ -133,7 +133,7 @@ def _load_nightly_dict() -> NightlyDict:
   # Build the `full_names_dict['dataset']['config']['version']` for both
   # nightly and stable version
   registered_ds = _full_names_to_dict(
-      tfds.core.registered.list_full_names())
+      tfds.core.load.list_full_names())
   stable_version_ds = _full_names_to_dict(stable_versions)
 
   # Nightly versions are `registered - stable`
@@ -218,14 +218,13 @@ def document_single_builder(builder):
     with futures.ThreadPoolExecutor(max_workers=WORKER_COUNT_CONFIGS) as tpool:
       config_builders = list(
           tpool.map(get_config_builder, builder.BUILDER_CONFIGS))
-  tmpl = get_mako_template('dataset')
   visu_doc_util = VisualizationDocUtil()
-  out_str = tmpl.render_unicode(
+  out_str = dataset_markdown_builder.get_markdown_string(
       builder=builder,
       config_builders=config_builders,
       visu_doc_util=visu_doc_util,
       nightly_doc_util=NightlyDocUtil(),
-  ).strip()
+  )
   schema_org_tmpl = get_mako_template('schema_org')
   schema_org_out_str = schema_org_tmpl.render_unicode(
       builder=builder,
@@ -236,15 +235,10 @@ def document_single_builder(builder):
   return out_str
 
 
-def make_module_to_builder_dict(datasets=None):
-  """Get all builders organized by module in nested dicts."""
-  # pylint: disable=g-long-lambda
-  # dict to hold tfds->image->mnist->[builders]
-  module_to_builder = collections.defaultdict(
-      lambda: collections.defaultdict(
-          lambda: collections.defaultdict(list)))
-  # pylint: enable=g-long-lambda
-
+def make_category_to_builders_dict(
+    datasets: Optional[List[str]] = None,
+) -> Dict[str, List[tfds.core.DatasetBuilder]]:
+  """Returns the `Dict[dataset_type, List[Builder]]`."""
   if not datasets:
     datasets = [
         name for name in tfds.list_builders() if name not in BUILDER_BLACKLIST
@@ -254,19 +248,22 @@ def make_module_to_builder_dict(datasets=None):
     builders = tpool.map(tfds.builder, datasets)
   print('Vanilla builders built, constructing module_to_builder dict...')
 
+  # Dict[dataset_type, List[Builder]]
+  category_to_builders = collections.defaultdict(list)
+
   for builder in builders:
-    module_name = builder.__class__.__module__
-    modules = module_name.split('.')
-    if 'testing' in modules:
+    module = type(builder).__module__
+    if not module.startswith('tensorflow_datasets.'):
+      raise AssertionError(f'Unexpected builder {type(builder)}: module')
+
+    module_parts = module.split('.')
+
+    if 'testing' in module_parts:
       continue
+    _, category, *_ = module_parts  # tfds.<category>.xyz
 
-    current_mod_ctr = module_to_builder
-    for mod in modules:
-      current_mod_ctr = current_mod_ctr[mod]
-    current_mod_ctr.append(builder)  # pytype: disable=attribute-error
-
-  module_to_builder = module_to_builder['tensorflow_datasets']
-  return module_to_builder
+    category_to_builders[category].append(builder)
+  return category_to_builders
 
 
 def dataset_docs_str(datasets=None):
@@ -284,19 +281,19 @@ def dataset_docs_str(datasets=None):
   """
 
   print('Retrieving the list of builders...')
-  module_to_builder = make_module_to_builder_dict(datasets)
-  sections = sorted(list(module_to_builder.keys()))
+  category_to_builders = make_category_to_builders_dict(datasets)
+  sections = sorted(list(category_to_builders.keys()))
   section_docs = collections.defaultdict(list)
 
   for section in sections:
-    builders = tf.nest.flatten(module_to_builder[section])
+    builders = category_to_builders[section]
     builders = sorted(builders, key=lambda b: b.name)
-    unused_ = get_mako_template('dataset')  # To warm cache.
     with futures.ThreadPoolExecutor(max_workers=WORKER_COUNT_DATASETS) as tpool:
       builder_docs = tpool.map(document_single_builder, builders)
-    builder_docs = [(builder.name, builder.MANUAL_DOWNLOAD_INSTRUCTIONS,
-                     builder_doc)
-                    for (builder, builder_doc) in zip(builders, builder_docs)]
+    builder_docs = [
+        (builder.name, builder.MANUAL_DOWNLOAD_INSTRUCTIONS, builder_doc)
+        for (builder, builder_doc) in zip(builders, builder_docs)
+    ]
     section_docs[section] = builder_docs
   tmpl = get_mako_template('catalog_overview')
   catalog_overview = tmpl.render_unicode().lstrip()
