@@ -13,36 +13,24 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Test utilities."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import contextlib
-import functools
 import io
 import os
 import subprocess
 import tempfile
-from typing import Iterator
+from typing import Any, Iterator
+from unittest import mock
 
-from absl.testing import absltest
-
-import dill
 import numpy as np
 import tensorflow.compat.v2 as tf
 
 from tensorflow_datasets.core import dataset_builder
 from tensorflow_datasets.core import dataset_info
-from tensorflow_datasets.core import dataset_utils
-from tensorflow_datasets.core import example_parser
-from tensorflow_datasets.core import example_serializer
 from tensorflow_datasets.core import features
 from tensorflow_datasets.core import splits
 from tensorflow_datasets.core import utils
-from tensorflow_datasets.testing import test_case
 
 
 @contextlib.contextmanager
@@ -157,11 +145,22 @@ class MockFs(object):
       raise FileNotFoundError('Cannot rename unknown file: {}'.format(from_))  # pytype: disable=name-error
     self.files[to] = self.files.pop(from_)
 
+  def _exists(self, path: str) -> bool:
+    """Returns True, if any file/directory exists."""
+    path = path.rstrip(os.path.sep)  # Normalize path
+    # Check full path existence
+    if path in self.files:
+      return True
+    # Check parent directory
+    path = path + os.path.sep
+    if any(f.startswith(path) for f in self.files):
+      return True
+    return False
+
   def mock(self):
-    return absltest.mock.patch.object(
-        tf.io,
-        'gfile',
-        exists=lambda path: path in self.files,
+    return mock_tf(
+        'tf.io.gfile',
+        exists=self._exists,
         makedirs=lambda _: None,
         # Used to get name of file as downloaded:
         listdir=self._list_directory,
@@ -170,64 +169,43 @@ class MockFs(object):
     )
 
 
-class FeatureExpectationItem(object):
-  """Test item of a FeatureExpectation."""
+@contextlib.contextmanager
+def mock_tf(symbol_name: str, *args: Any, **kwargs: Any) -> Iterator[None]:
+  """Patch TF API.
 
-  def __init__(
-      self,
-      value,
-      expected=None,
-      expected_serialized=None,
-      decoders=None,
-      dtype=None,
-      shape=None,
-      raise_cls=None,
-      raise_msg=None):
-    self.value = value
-    self.expected = expected
-    self.expected_serialized = expected_serialized
-    self.decoders = decoders
-    self.dtype = dtype
-    self.shape = shape
-    if not decoders and (dtype is not None or shape is not None):
-      raise ValueError('dtype and shape should only be set with transform')
-    self.raise_cls = raise_cls
-    self.raise_msg = raise_msg
+  This function is similar to `mock.patch.object`, but patch both
+  `tf.Xyz` and `tf.compat.v2.Xyz`.
 
+  Args:
+    symbol_name: Symbol to patch (e.g. `tf.io.gfile`)
+    *args: Arguments to forward to `mock.patch.object`
+    **kwargs: Arguments to forward to `mock.patch.object`
 
-class SubTestCase(test_case.TestCase):
-  """Adds subTest() context manager to the TestCase if supported.
-
-  Note: To use this feature, make sure you call super() in setUpClass to
-  initialize the sub stack.
+  Yields:
+    None
   """
+  # pylint: disable=g-import-not-at-top,reimported
+  import tensorflow as tf_lib1
+  import tensorflow.compat.v2 as tf_lib2
+  # pylint: enable=g-import-not-at-top,reimported
 
-  @classmethod
-  def setUpClass(cls):
-    super(SubTestCase, cls).setUpClass()
-    cls._sub_test_stack = []
+  tf_symbol, *tf_submodules, symbol_name = symbol_name.split('.')
+  if tf_symbol != 'tf':
+    raise ValueError('Symbol name to patch should start by `tf`.')
 
-  @contextlib.contextmanager
-  def _subTest(self, test_str):
-    self._sub_test_stack.append(test_str)
-    sub_test_str = '/'.join(self._sub_test_stack)
-    with self.subTest(sub_test_str):
-      yield
-    self._sub_test_stack.pop()
-
-  def assertAllEqualNested(self, d1, d2):
-    """Same as assertAllEqual but compatible with nested dict."""
-    if isinstance(d1, dict):
-      # assertAllEqual do not works well with dictionaries so assert
-      # on each individual elements instead
-      zipped_examples = utils.zip_nested(d1, d2, dict_only=True)
-      utils.map_nested(
-          lambda x: self.assertAllEqual(x[0], x[1]),
-          zipped_examples,
-          dict_only=True,
+  with contextlib.ExitStack() as stack:
+    # Patch both `tf` and `tf.compat.v2`
+    for tf_lib in (tf_lib1, tf_lib2):
+      # Recursivelly load the submodules/subobjects (e.g. `tf.io.gfile`)
+      module = tf_lib
+      for submodule in tf_submodules:
+        module = getattr(module, submodule)
+      getattr(module, symbol_name)  # Trigger the lazy-loading of the TF API.
+      # Patch the module/object
+      stack.enter_context(
+          mock.patch.object(module, symbol_name, *args, **kwargs)
       )
-    else:
-      self.assertAllEqual(d1, d2)
+    yield
 
 
 def run_in_graph_and_eager_modes(func=None,
@@ -280,6 +258,7 @@ def run_in_graph_and_eager_modes(func=None,
 
   def decorator(f):
     """Decorator for a method."""
+
     def decorated(self, *args, **kwargs):
       """Run the decorated test method."""
       if not tf.executing_eagerly():
@@ -304,144 +283,6 @@ def run_in_graph_and_eager_modes(func=None,
   return decorator
 
 
-class RaggedConstant(object):
-  """Container of tf.ragged.constant values.
-
-  This simple wrapper forward the arguments to delay the RaggedTensor
-  construction after `@run_in_graph_and_eager_modes` has been called.
-  This is required to avoid incompabilities between Graph/eager.
-  """
-
-  def __init__(self, *args, **kwargs):
-    self._args = args
-    self._kwargs = dict(kwargs)
-
-  def build(self):
-    return tf.ragged.constant(*self._args, **self._kwargs)
-
-
-class FeatureExpectationsTestCase(SubTestCase):
-  """Tests FeatureExpectations with full encode-decode."""
-
-  @run_in_graph_and_eager_modes()
-  def assertFeature(self, feature, shape, dtype, tests, serialized_info=None):
-    """Test the given feature against the predicates."""
-
-    # Check the shape/dtype
-    with self._subTest('shape'):
-      self.assertEqual(feature.shape, shape)
-    with self._subTest('dtype'):
-      self.assertEqual(feature.dtype, dtype)
-
-    # Check the serialized features
-    if serialized_info is not None:
-      with self._subTest('serialized_info'):
-        self.assertEqual(
-            serialized_info,
-            feature.get_serialized_info(),
-        )
-
-    # Create the feature dict
-    fdict = features.FeaturesDict({'inner': feature})
-    fdict._set_top_level()  # pylint: disable=protected-access
-
-    for i, test in enumerate(tests):
-      with self._subTest(str(i)):
-        self.assertFeatureTest(
-            fdict=fdict,
-            test=test,
-            feature=feature,
-            shape=shape,
-            dtype=dtype,
-        )
-
-  def assertFeatureTest(self, fdict, test, feature, shape, dtype):
-    """Test that encode=>decoding of a value works correctly."""
-    # test feature.encode_example can be pickled and unpickled for beam.
-    dill.loads(dill.dumps(feature.encode_example))
-
-    input_value = {'inner': test.value}
-
-    if test.raise_cls is not None:
-      with self._subTest('raise'):
-        if not test.raise_msg:
-          raise ValueError(
-              'test.raise_msg should be set with {} for test {}'.format(
-                  test.raise_cls, type(feature)))
-        with self.assertRaisesWithPredicateMatch(
-            test.raise_cls, test.raise_msg):
-          features_encode_decode(fdict, input_value, decoders=test.decoders)
-    else:
-      # Test the serialization only
-      if test.expected_serialized is not None:
-        with self._subTest('out_serialize'):
-          self.assertEqual(
-              test.expected_serialized,
-              feature.encode_example(test.value),
-          )
-
-      # Test serialization + decoding from disk
-      with self._subTest('out'):
-        out_tensor, out_numpy = features_encode_decode(
-            fdict,
-            input_value,
-            decoders={'inner': test.decoders},
-        )
-        out_tensor = out_tensor['inner']
-        out_numpy = out_numpy['inner']
-
-        # Assert the returned type match the expected one
-        with self._subTest('dtype'):
-          out_dtypes = tf.nest.map_structure(lambda s: s.dtype, out_tensor)
-          self.assertEqual(out_dtypes, test.dtype or feature.dtype)
-        with self._subTest('shape'):
-          # For shape, because (None, 3) match with (5, 3), we use
-          # tf.TensorShape.assert_is_compatible_with on each of the elements
-          expected_shape = feature.shape if test.shape is None else test.shape
-          out_shapes = utils.zip_nested(out_tensor, expected_shape)
-          utils.map_nested(
-              lambda x: x[0].shape.assert_is_compatible_with(x[1]),
-              out_shapes
-          )
-
-        # Assert value
-        with self._subTest('out_value'):
-          # Eventually construct the tf.RaggedTensor
-          expected = tf.nest.map_structure(
-              lambda t: t.build() if isinstance(t, RaggedConstant) else t,
-              test.expected)
-          self.assertAllEqualNested(out_numpy, expected)
-
-
-def features_encode_decode(features_dict, example, decoders):
-  """Runs the full pipeline: encode > write > tmp files > read > decode."""
-  # Encode example
-  encoded_example = features_dict.encode_example(example)
-
-  # Serialize/deserialize the example
-  specs = features_dict.get_serialized_info()
-  serializer = example_serializer.ExampleSerializer(specs)
-  parser = example_parser.ExampleParser(specs)
-
-  serialized_example = serializer.serialize_example(encoded_example)
-  ds = tf.data.Dataset.from_tensors(serialized_example)
-  ds = ds.map(parser.parse_example)
-
-  # Decode the example
-  decode_fn = functools.partial(
-      features_dict.decode_example,
-      decoders=decoders,
-  )
-  ds = ds.map(decode_fn)
-
-  if tf.executing_eagerly():
-    out_tensor = next(iter(ds))
-  else:
-    out_tensor = tf.compat.v1.data.make_one_shot_iterator(ds).get_next()
-  out_numpy = dataset_utils.as_numpy(out_tensor)
-  return out_tensor, out_numpy
-
-
 class DummyDatasetSharedGenerator(dataset_builder.GeneratorBasedBuilder):
   """Test DatasetBuilder."""
 
@@ -542,7 +383,7 @@ def mock_kaggle_api(err_msg=None):
       f.write(competition_or_dataset)
     return 'Downloading {} to {}'.format(competition_or_dataset, fpath)
 
-  with absltest.mock.patch('subprocess.check_output', check_output):
+  with mock.patch('subprocess.check_output', check_output):
     yield
 
 
@@ -564,4 +405,3 @@ class DummyParser(object):
 
   def parse_example(self, ex):
     return ex
-
