@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """C4 dataset based on Common Crawl."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import json
 import os
 
@@ -50,12 +45,18 @@ _CITATION = """
   eprint = {1910.10683},
 }
 """
-_VERSION = tfds.core.Version("2.3.0", "Deduplicate lines within a page.")
+_VERSION = tfds.core.Version("2.3.1")
 
 _SUPPORTED_VERSIONS = [
-    tfds.core.Version("2.2.1", "Update dataset_info.json"),
+    tfds.core.Version("2.3.0"),
+    tfds.core.Version("2.2.1"),
     tfds.core.Version("2.2.0"),
 ]
+RELEASE_NOTES = {
+    "2.3.1": "Hashing change.",
+    "2.3.0": "Deduplicate lines within a page.",
+    "2.2.1": "Update dataset_info.json",
+}
 
 _DOWNLOAD_HOST = "https://commoncrawl.s3.amazonaws.com"
 _WET_PATH_URL = "https://commoncrawl.s3.amazonaws.com/crawl-data/CC-MAIN-{cc_version}/wet.paths.gz"
@@ -75,8 +76,8 @@ _DEFAULT_WEBTEXTLIKE_CC_VERSIONS = (  # August 2018 - July 2019
 class C4Config(tfds.core.BuilderConfig):
   """BuilderConfig for C4 dataset."""
 
-  @tfds.core.disallow_positional_args
   def __init__(self,
+               *,
                language,
                cc_versions=None,
                clean=True,
