@@ -15,10 +15,6 @@
 
 """clinc_oos dataset."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from tensorflow_datasets import testing
 from tensorflow_datasets.text import clinc_oos
 
