@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """The Multi-Genre NLI Corpus."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 
 import tensorflow.compat.v2 as tf
@@ -60,18 +55,18 @@ ROOT_URL = "https://cims.nyu.edu/~sbowman/multinli/multinli_1.0.zip"
 class MultiNLIMismatchConfig(tfds.core.BuilderConfig):
   """BuilderConfig for MultiNLI Mismatch."""
 
-  @tfds.core.disallow_positional_args
-  def __init__(self, text_encoder_config=None, **kwargs):
+  def __init__(self, *, text_encoder_config=None, **kwargs):
     """BuilderConfig for MultiNLI Mismatch.
 
     Args:
-      text_encoder_config: `tfds.features.text.TextEncoderConfig`, configuration
-        for the `tfds.features.text.TextEncoder` used for the features feature.
+      text_encoder_config: `tfds.deprecated.text.TextEncoderConfig`,
+        configuration for the `tfds.deprecated.text.TextEncoder` used for the
+        features feature.
       **kwargs: keyword arguments forwarded to super.
     """
     super(MultiNLIMismatchConfig, self).__init__(**kwargs)
     self.text_encoder_config = (
-        text_encoder_config or tfds.features.text.TextEncoderConfig())
+        text_encoder_config or tfds.deprecated.text.TextEncoderConfig())
 
 
 class MultiNLIMismatch(tfds.core.GeneratorBasedBuilder):
