@@ -13,14 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 # -*- coding: utf-8 -*-
 """Tests for OPUS translate dataset module."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from tensorflow_datasets import testing
 import tensorflow_datasets.public_api as tfds
 from tensorflow_datasets.translate import opus
